Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Shield.

Actions, resources, and condition keys for AWS Shield - Service Authorization Reference

# Actions, resources, and condition keys for AWS Shield

AWS Shield (service prefix: `shield` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Shield
- Resource types defined by AWS Shield
- Condition keys for AWS Shield

## Actions defined by AWS Shield

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateDRTLogBucket | Grants permission to authorize the DDoS Response team to access the specified Amazon S3 bucket containing your flow logs | Write |  |  | s3:GetBucketPolicy s3:PutBucketPolicy
AssociateDRTRole | Grants permission to authorize the DDoS Response team using the specified role, to access your AWS account to assist with DDoS attack mitigation during potential attacks | Write |  |  | iam:GetRole iam:ListAttachedRolePolicies iam:PassRole
AssociateHealthCheck | Grants permission to add health-based detection to the Shield Advanced protection for a resource | Write | protection* |  | route53:GetHealthCheck
| aws:ResourceTag/${TagKey} |
AssociateProactiveEngagementDetails | Grants permission to initialize proactive engagement and set the list of contacts for the DDoS Response Team (DRT) to use | Write |  |  |
CreateProtection | Grants permission to activate DDoS protection service for a given resource ARN | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateProtectionGroup | Grants permission to create a grouping of protected resources so they can be handled as a collective | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateSubscription | Grants permission to activate subscription | Write |  |  |
DeleteProtection | Grants permission to delete an existing protection | Write | protection* |  |
| aws:ResourceTag/${TagKey} |
DeleteProtectionGroup | Grants permission to remove the specified protection group | Write | protection-group* |  |
| aws:ResourceTag/${TagKey} |
DeleteSubscription | Grants permission to deactivate subscription | Write |  |  |
DescribeAttack | Grants permission to get attack details | Read | attack* |  |
DescribeAttackStatistics | Grants permission to describe information about the number and type of attacks AWS Shield has detected in the last year | Read |  |  |
DescribeDRTAccess | Grants permission to describe the current role and list of Amazon S3 log buckets used by the DDoS Response team to access your AWS account while assisting with attack mitigation | Read |  |  |
DescribeEmergencyContactSettings | Grants permission to list the email addresses that the DRT can use to contact you during a suspected attack | Read |  |  |
DescribeProtection | Grants permission to get protection details | Read | protection* |  |
| aws:ResourceTag/${TagKey} |
DescribeProtectionGroup | Grants permission to describe the specification for the specified protection group | Read | protection-group* |  |
| aws:ResourceTag/${TagKey} |
DescribeSubscription | Grants permission to get subscription details, such as start time | Read |  |  |
DisableApplicationLayerAutomaticResponse | Grants permission to disable application layer automatic response for Shield Advanced protection for a resource | Write |  |  |
DisableProactiveEngagement | Grants permission to remove authorization from the DDoS Response Team (DRT) to notify contacts about escalations | Write |  |  |
DisassociateDRTLogBucket | Grants permission to remove the DDoS Response team's access to the specified Amazon S3 bucket containing your flow logs | Write |  |  | s3:DeleteBucketPolicy s3:GetBucketPolicy s3:PutBucketPolicy
DisassociateDRTRole | Grants permission to remove the DDoS Response team's access to your AWS account | Write |  |  |
DisassociateHealthCheck | Grants permission to remove health-based detection from the Shield Advanced protection for a resource | Write | protection* |  |
| aws:ResourceTag/${TagKey} |
EnableApplicationLayerAutomaticResponse | Grants permission to enable application layer automatic response for Shield Advanced protection for a resource | Write |  |  | cloudfront:GetDistribution iam:CreateServiceLinkedRole iam:GetRole
EnableProactiveEngagement | Grants permission to authorize the DDoS Response Team (DRT) to use email and phone to notify contacts about escalations | Write |  |  |
GetSubscriptionState | Grants permission to get subscription state | Read |  |  |
ListAttacks | Grants permission to list all existing attacks | List |  |  |
ListProtectionGroups | Grants permission to retrieve the protection groups for the account | List |  |  |
ListProtections | Grants permission to list all existing protections | List |  |  |
ListResourcesInProtectionGroup | Grants permission to retrieve the resources that are included in the protection group | List | protection-group* |  |
ListTagsForResource | Grants permission to get information about AWS tags for a specified Amazon Resource Name (ARN) in AWS Shield | Read | protection |  |
protection-group |  |
TagResource | Grants permission to add or updates tags for a resource in AWS Shield | Tagging | protection |  |
protection-group |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from a resource in AWS Shield | Tagging | protection |  |
protection-group |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateApplicationLayerAutomaticResponse | Grants permission to update application layer automatic response for Shield Advanced protection for a resource | Write |  |  |
UpdateEmergencyContactSettings | Grants permission to update the details of the list of email addresses that the DRT can use to contact you during a suspected attack | Write |  |  |
UpdateProtectionGroup | Grants permission to update an existing protection group | Write | protection-group* |  |
| aws:ResourceTag/${TagKey} |
UpdateSubscription | Grants permission to update the details of an existing subscription | Write |  |  |

## Resource types defined by AWS Shield

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
attack | `arn:$ { Partition}:shield::$ { Account}:attack/$ { Id}` |
protection | `arn:$ { Partition}:shield::$ { Account}:protection/$ { Id}` | aws:ResourceTag/${TagKey}
protection-group | `arn:$ { Partition}:shield::$ { Account}:protection-group/$ { Id}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Shield

AWS Shield defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.